var structcs__param__sles__t =
[
    [ "allow_no_op", "structcs__param__sles__t.html#a07a2c999b0a6a7acf3fdb9a99624c294", null ],
    [ "amg_type", "structcs__param__sles__t.html#ac935e92cb8eaa17451a56e76d2c525c8", null ],
    [ "context_param", "structcs__param__sles__t.html#a429cb6aa8962ff89a156930357bb9a87", null ],
    [ "cvg_param", "structcs__param__sles__t.html#a0309e20bed7b8079ddcc12fc3c6cfad1", null ],
    [ "field_id", "structcs__param__sles__t.html#a0b20bee1f92ba8b58aaf320f662e8e61", null ],
    [ "mat_is_sym", "structcs__param__sles__t.html#a17e40cfe28f9594bbb03dd2cdd6e52bc", null ],
    [ "name", "structcs__param__sles__t.html#a5ac083a645d964373f022d03df4849c8", null ],
    [ "need_flexible", "structcs__param__sles__t.html#a6be5b54efa97cfe2bb23a0934c9b1457", null ],
    [ "precond", "structcs__param__sles__t.html#a9199badebb6cfb445668eb2f3e7c8378", null ],
    [ "precond_block_type", "structcs__param__sles__t.html#a04c120aa248b8863b05e9c38f703c5bd", null ],
    [ "resnorm_type", "structcs__param__sles__t.html#a644f9aead451cf8d7ae6a50e477df1cd", null ],
    [ "restart", "structcs__param__sles__t.html#a9ebd0610b02b8fad4f28c6deadea0c7d", null ],
    [ "solver", "structcs__param__sles__t.html#aee43f0c04c1a9bd6bf487ee2de4657f1", null ],
    [ "solver_class", "structcs__param__sles__t.html#a97516782b3fb1a4bdafb6b36c9c8cb68", null ],
    [ "verbosity", "structcs__param__sles__t.html#a1bdcfae3209cbd96db35a2ae356fa15e", null ]
];